Re-exports
pub use crate::types::AgentResult;pub use crate::types::ApprovalDecision;pub use crate::types::ApprovalRequest;pub use crate::types::RiskLevel;pub use crate::types::SessionId;
Structs
- Agent
Builder - Agent
Runtime - Agent
Session - Allow
AllApproval Handler - Context
Window Manager - Deny
AllApproval Handler - InMemory
Session Store - Post
LlmCtx - PreLlm
Ctx - Retry
OnError - Continue on tool failure, feeding the error back to the model
- Stop
OnError - Default strategy: stop on tool failure.
- User
Message Ctx
Enums
- Tool
Error Action - Action taken by the runtime after a tool execution failure
Traits
- Approval
Handler - Middleware
- Session
Store - Session Persistence Adapter
- Tool
Error Recovery - Recovery strategy after a tool execution failure