Module auto_continue

Module auto_continue 

Structs

AutoContinueMiddleware
Middleware that automatically injects a continuation message when the LLM response is truncated by the token limit (e.g. max_tokens / length) and no tool calls are present.