Re-exports
pub use crate::types::AgentResult;pub use crate::types::ApprovalDecision;pub use crate::types::ApprovalRequest;pub use crate::types::RiskLevel;pub use crate::types::SessionId;
Structs
- Agent
Builder - Agent
Runtime - Agent
Session - Allow
AllApproval Handler - Circuit
Breaker - A circuit breaker that tracks consecutive failures and temporarily disables execution when a threshold is exceeded.
- Consecutive
Failure Recovery - Recovery strategy that tracks consecutive failures per tool and stops after a limit.
- Context
Window Manager - Default
Pipeline - Default pipeline: ToolPolicy hooks + timeout + output truncation.
- Deny
AllApproval Handler - InMemory
Session Store - Post
LlmCtx - PreLlm
Ctx - Retry
OnError - Continue on tool failure, feeding the error back to the model
- Stop
OnError - Default strategy: stop on tool failure.
- Tool
Enforcement Config - Tool
Enforcement Middleware - Turn
Fact Middleware - Turn fact summary middleware — injects structured facts from the previous turn’s tool results into the next user message.
- Turn
Tool Limit Middleware - Middleware that enforces a hard limit on tool calls per turn.
- User
Message Ctx
Enums
- Circuit
State - Circuit breaker states.
- Tool
Error Action - Action taken by the runtime after a tool execution failure
Traits
- Approval
Handler - Trait for handling tool approval requests.
- Middleware
- Session
Store - Session Persistence Adapter
- Tool
Error Recovery - Recovery strategy after a tool execution failure
- Tool
Execution Pipeline - Pure execution pipeline — cares about how to safely execute a tool.