Module engine

Module engine 

Re-exports

pub use crate::types::AgentResult;
pub use crate::types::ApprovalDecision;
pub use crate::types::ApprovalRequest;
pub use crate::types::RiskLevel;
pub use crate::types::SessionId;

Structs

AbortOnFailure
Always aborts on failure.
AgentBuilder
AgentRuntime
AgentSession
AllowAllApprovalHandler
AlternativeAction
AlwaysContinue
Always continues.
ContextWindowManager
DenyAllApprovalHandler
InMemoryPlanStore
InMemorySessionStore
PlanExecTool
PlanExecTool is a domain-agnostic tool for executing previously created plans.
PlanOrchestrator
PlanOrchestrator is a domain-agnostic tool for creating execution plans. It delegates plan generation to a PlanGenerator implementation and stores the plan via a PlanStore.
PostLlmCtx
PreLlmCtx
ReflectionResult
ReflexionContext
RetryOnError
Continue on tool failure, feeding the error back to the model
StepHistoryEntry
StopOnError
Default strategy: stop on tool failure.
StreamingJsonParser
Parses JSON objects of type T from a stream of text chunks.
ToolEnforcementConfig
ToolEnforcementMiddleware
UserMessageCtx

Enums

ToolErrorAction
Action taken by the runtime after a tool execution failure

Traits

ApprovalHandler
Middleware
PlanGenerator
Generates an ExecutionPlan from a high-level objective.
PlanStore
RecoveryStrategy
Decides what to do when a step fails.
ReflexionHandler
SessionStore
Session Persistence Adapter
StepContinuePolicy
Decides whether the plan should continue executing a given step.
StepExecutor
Executes a single PlanStep and returns its result.
ToolErrorRecovery
Recovery strategy after a tool execution failure