Re-exports
pub use crate::types::AgentResult;pub use crate::types::ApprovalDecision;pub use crate::types::ApprovalRequest;pub use crate::types::RiskLevel;pub use crate::types::SessionId;
Structs
- Abort
OnFailure - Always aborts on failure.
- Agent
Builder - Agent
Runtime - Agent
Session - Allow
AllApproval Handler - Alternative
Action - Always
Continue - Always continues.
- Context
Window Manager - Deny
AllApproval Handler - InMemory
Plan Store - InMemory
Session Store - Plan
Exec Tool - PlanExecTool is a domain-agnostic tool for executing previously created plans.
- Plan
Orchestrator - PlanOrchestrator is a domain-agnostic tool for creating execution plans.
It delegates plan generation to a
PlanGeneratorimplementation and stores the plan via aPlanStore. - Post
LlmCtx - PreLlm
Ctx - Reflection
Result - Reflexion
Context - Retry
OnError - Continue on tool failure, feeding the error back to the model
- Step
History Entry - Stop
OnError - Default strategy: stop on tool failure.
- Streaming
Json Parser - Parses JSON objects of type
Tfrom a stream of text chunks. - Tool
Enforcement Config - Tool
Enforcement Middleware - User
Message Ctx
Enums
- Tool
Error Action - Action taken by the runtime after a tool execution failure
Traits
- Approval
Handler - Middleware
- Plan
Generator - Generates an
ExecutionPlanfrom a high-level objective. - Plan
Store - Recovery
Strategy - Decides what to do when a step fails.
- Reflexion
Handler - Session
Store - Session Persistence Adapter
- Step
Continue Policy - Decides whether the plan should continue executing a given step.
- Step
Executor - Executes a single
PlanStepand returns its result. - Tool
Error Recovery - Recovery strategy after a tool execution failure