Module engine

Module engine 

Re-exports

pub use crate::types::AgentResult;
pub use crate::types::ApprovalDecision;
pub use crate::types::ApprovalRequest;
pub use crate::types::RiskLevel;
pub use crate::types::SessionId;

Structs

AgentBuilder
AgentRuntime
AgentSession
AllowAllApprovalHandler
ContextWindowManager
DenyAllApprovalHandler
InMemorySessionStore
PostLlmCtx
PreLlmCtx
RetryOnError
Continue on tool failure, feeding the error back to the model
StopOnError
Default strategy: stop on tool failure.
UserMessageCtx

Enums

ToolErrorAction
Action taken by the runtime after a tool execution failure

Traits

ApprovalHandler
Middleware
SessionStore
Session Persistence Adapter
ToolErrorRecovery
Recovery strategy after a tool execution failure