ToolErrorRecovery

Trait ToolErrorRecovery 

pub trait ToolErrorRecovery: Send + Sync {
    // Required method
    fn on_error(
        &self,
        _session_id: &SessionId,
        _tool_names: &[String],
        _error: &AgentError,
    ) -> AgentResult<ToolErrorAction>;
}
Recovery strategy after a tool execution failure

Defaults to StopOnError, following the lightweight kernel design of conservative defaults and strategy injection. Upper-layer agents can inject custom strategies such as RetryOnError.

Required Methods

fn on_error( &self, _session_id: &SessionId, _tool_names: &[String], _error: &AgentError, ) -> AgentResult<ToolErrorAction>

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors