pub struct DenyAllToolPolicy;Expand description
A ToolPolicy that requires approval for every tool call.
Combined with a deny-all approval handler, this denies every tool for the
agent that carries it. Used by multi-agent runtimes as a fallback when a
child should have “no permission” but its parent has no ToolPolicy of
its own to inherit (so there is no notion of which tools are “dangerous”).